# Based on https://www.geospatial.jp/ckan/dataset/plateau

# %%

base_city_list = [
    {
        "dataset_id": "plateau-01100-sapporo-shi-2020",
        "city_name": "北海道札幌市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-01100-sapporo-shi-2020",
        "citygml": "d702b5a8-f2cf-4db9-9d1b-4284e7702bb5",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-01100-sapporo-shi-2020",
        "city_name": "北海道札幌市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-01100-sapporo-shi-2020",
        "citygml": "10a832b4-d895-4999-b4c6-c6201cc85023",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-01100-sapporo-shi-2020",
        "city_name": "北海道札幌市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-01100-sapporo-shi-2020",
        "citygml": "5236a116-35be-46ea-a4d0-e840cc7ab3ac",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-01639-sarabetsu-mura-2022",
        "city_name": "北海道更別村",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-01639-sarabetsu-mura-2022",
        "citygml": "35daef49-396e-4c21-9e5c-d602e3a1833b",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-01639-sarabetsu-mura-2023",
        "city_name": "北海道更別村",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-01639-sarabetsu-mura-2023",
        "citygml": "0e5e0f8d-d769-4630-b9dc-d8bbfaf7f0db",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-01205-muroran-shi-2022",
        "city_name": "北海道室蘭市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-01205-muroran-shi-2022",
        "citygml": "a6081835-a31c-419f-8c5f-8f296c518a88",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-01205-muroran-shi-2022",
        "city_name": "北海道室蘭市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-01205-muroran-shi-2022",
        "citygml": "92bd06f2-7421-4ab9-aeeb-d886887c8a3a",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-02208-mutsu-shi-2022",
        "city_name": "青森県むつ市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-02208-mutsu-shi-2022",
        "citygml": "8f7a3d5c-a673-490c-a814-394cf4331553",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-02208-mutsu-shi-2022",
        "city_name": "青森県むつ市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-02208-mutsu-shi-2022",
        "citygml": "5f780e16-816d-4239-a345-83c5c0fe8919",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-03201-morioka-shi-2022",
        "city_name": "岩手県盛岡市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-03201-morioka-shi-2022",
        "citygml": "94b62d49-9c3f-4826-8016-8a7816e075cd",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-03201-morioka-shi-2023",
        "city_name": "岩手県盛岡市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-03201-morioka-shi-2023",
        "citygml": "8c300aa0-9bf0-4d06-979b-037f740dd9c7",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-04100-sendai-shi-2022",
        "city_name": "宮城県仙台市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-04100-sendai-shi-2022",
        "citygml": "98560555-9021-43c3-b319-7be59db97814",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-04100-sendai-shi-2022",
        "city_name": "宮城県仙台市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-04100-sendai-shi-2022",
        "citygml": "a1f35479-9339-4b97-a416-ff120c138db5",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-07204-iwaki-shi-2020",
        "city_name": "福島県いわき市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-07204-iwaki-shi-2020",
        "citygml": "25835db2-2559-42fc-9107-fb42f706b43b",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-07204-iwaki-shi-2020",
        "city_name": "福島県いわき市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-07204-iwaki-shi-2020",
        "citygml": "e2b450ed-7c08-4324-8616-703a5952d0e3",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-07204-iwaki-shi-2020",
        "city_name": "福島県いわき市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-07204-iwaki-shi-2020",
        "citygml": "6400e9dc-3dd2-46ad-821f-9072122f44e0",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-07203-koriyama-shi-2020",
        "city_name": "福島県郡山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-07203-koriyama-shi-2020",
        "citygml": "66b2335f-197e-4fc9-91c7-882ef57b211c",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-07203-koriyama-shi-2020",
        "city_name": "福島県郡山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-07203-koriyama-shi-2020",
        "citygml": "301b61cc-efec-45c5-b878-48a18128d073",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-07203-koriyama-shi-2020",
        "city_name": "福島県郡山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-07203-koriyama-shi-2020",
        "citygml": "ddbc5880-d584-4ce1-bfeb-0f8f46f0135b",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-07205-shirakawa-shi-2020",
        "city_name": "福島県白河市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-07205-shirakawa-shi-2020",
        "citygml": "58d43179-2b6d-42a5-9201-493c16f9a4fa",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-07205-shirakawa-shi-2020",
        "city_name": "福島県白河市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-07205-shirakawa-shi-2020",
        "citygml": "d36bd3e2-a909-48ae-8b51-01acca794379",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-07205-shirakawa-shi-2020",
        "city_name": "福島県白河市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-07205-shirakawa-shi-2020",
        "citygml": "91c776c5-142a-456c-83d4-7915e8cdb9f6",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-07212-minamisouma-shi-2022",
        "city_name": "福島県南相馬市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-07212-minamisouma-shi-2022",
        "citygml": "cc66cc2f-926a-4fa7-965f-32e25b5b0699",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-07212-minamisouma-shi-2022",
        "city_name": "福島県南相馬市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-07212-minamisouma-shi-2022",
        "citygml": "2784b256-8649-4375-85d6-ca29ff6de3d6",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-08546-sakai-machi-2023",
        "city_name": "茨城県境町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-08546-sakai-machi-2023",
        "citygml": "e250d245-c716-40ea-97c3-0e4c6d8a255d",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-08234-hokota-shi-2020",
        "city_name": "茨城県鉾田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-08234-hokota-shi-2020",
        "citygml": "127a5a36-9934-4f1c-af05-a9b7818bd3c6",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-08234-hokota-shi-2020",
        "city_name": "茨城県鉾田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-08234-hokota-shi-2020",
        "citygml": "02b00898-7370-467e-be92-b7d8a5e00a5a",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-08234-hokota-shi-2022",
        "city_name": "茨城県鉾田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-08234-hokota-shi-2022",
        "citygml": "6c57404e-1654-43da-a62d-db0dbf8399a2",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-08234-hokota-shi-2022",
        "city_name": "茨城県鉾田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-08234-hokota-shi-2022",
        "citygml": "1ee20390-7283-47ac-8d74-8db868a136bc",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-08220-tsukuba-shi-2022",
        "city_name": "茨城県つくば市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-08220-tsukuba-shi-2022",
        "citygml": "81551ff2-1680-42a8-a27c-3c01e0bc80ce",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-08220-tsukuba-shi-2023",
        "city_name": "茨城県つくば市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-08220-tsukuba-shi-2023",
        "citygml": "2636320a-5ff8-4b58-ac63-fafe553c2a69",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-09201-utsunomiya-shi-2020",
        "city_name": "栃木県宇都宮市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-09201-utsunomiya-shi-2020",
        "citygml": "2604a874-85e8-4b22-8b50-badd34c4edf8",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-09201-utsunomiya-shi-2020",
        "city_name": "栃木県宇都宮市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-09201-utsunomiya-shi-2020",
        "citygml": "caa24ca5-5999-4f22-9d8e-8efb9df2cd2c",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-09201-utsunomiya-shi-2023",
        "city_name": "栃木県宇都宮市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-09201-utsunomiya-shi-2023",
        "citygml": "38d82e30-ed98-455c-b4c9-b18a0201c56a",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-10203-kiryu-shi-2020",
        "city_name": "群馬県桐生市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-10203-kiryu-shi-2020",
        "citygml": "4d5c750e-4124-4bf9-a37c-3f60e23aa10b",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-10203-kiryu-shi-2020",
        "city_name": "群馬県桐生市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-10203-kiryu-shi-2020",
        "citygml": "19a88dda-c5a9-4019-8436-884355a8b3c4",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-10203-kiryu-shi-2020",
        "city_name": "群馬県桐生市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-10203-kiryu-shi-2020",
        "citygml": "b947726e-c869-4ab9-9483-081ede143038",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-10207-tatebayashi-shi-2020",
        "city_name": "群馬県館林市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-10207-tatebayashi-shi-2020",
        "citygml": "1a03a72a-cee8-48e8-bf7e-3e565f1f1081",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-10207-tatebayashi-shi-2020",
        "city_name": "群馬県館林市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-10207-tatebayashi-shi-2020",
        "citygml": "856e8337-cea5-4529-b681-22eb0b83f106",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-10207-tatebayashi-shi-2020",
        "city_name": "群馬県館林市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-10207-tatebayashi-shi-2020",
        "citygml": "675c8180-e02f-4e5c-ba6c-fc1f47c0ea8f",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-10201-maebashi-shi-2023",
        "city_name": "群馬県前橋市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-10201-maebashi-shi-2023",
        "citygml": "93d83ea7-9f16-4a46-be33-6768b227c982",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11214-kasukabe-shi-2023",
        "city_name": "埼玉県春日部市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11214-kasukabe-shi-2023",
        "citygml": "887d7782-e823-4b02-9a33-a7a62ad8021d",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11210-kazo-shi-2023",
        "city_name": "埼玉県加須市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11210-kazo-shi-2023",
        "citygml": "126fcd3f-21cf-406f-869d-8da6cdd3ef53",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11232-kuki-shi-2023",
        "city_name": "埼玉県久喜市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11232-kuki-shi-2023",
        "citygml": "feb9198a-03e4-4c08-9264-9fc9e646447a",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11202-kumagaya-shi-2020",
        "city_name": "埼玉県熊谷市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11202-kumagaya-shi-2020",
        "citygml": "88991128-7e89-47f7-ac38-54aedeec4a93",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-11202-kumagaya-shi-2020",
        "city_name": "埼玉県熊谷市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11202-kumagaya-shi-2020",
        "citygml": "531c5b69-98b1-4d9f-ad11-89b95c450779",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-11202-kumagaya-shi-2023",
        "city_name": "埼玉県熊谷市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11202-kumagaya-shi-2023",
        "citygml": "e75b137d-6acb-42aa-978c-fefd7948c1b5",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11222-koshigaya-shi-2023",
        "city_name": "埼玉県越谷市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11222-koshigaya-shi-2023",
        "citygml": "3ce5c342-4a3a-44a3-a75f-8bd6d6cbf237",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11100-saitama-shi-2020",
        "city_name": "埼玉県さいたま市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11100-saitama-shi-2020",
        "citygml": "114a6d9e-d991-4f19-b686-ebcf5b74719a",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-11100-saitama-shi-2020",
        "city_name": "埼玉県さいたま市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11100-saitama-shi-2020",
        "citygml": "f7bfab09-ae92-4cec-ae9e-51fe5f6fbcd7",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-11100-saitama-shi-2022",
        "city_name": "埼玉県さいたま市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11100-saitama-shi-2022",
        "citygml": "fbbf84ed-a6a4-4179-8933-f7b144d8e320",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-11100-saitama-shi-2023",
        "city_name": "埼玉県さいたま市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11100-saitama-shi-2023",
        "citygml": "16b3b880-93a1-47f5-a1c6-68761a5463ae",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11246-shiraoka-shi-2023",
        "city_name": "埼玉県白岡市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11246-shiraoka-shi-2023",
        "citygml": "8498f3ea-85b2-43f0-80dc-6421c2df9cc1",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11464-sugito-machi-2023",
        "city_name": "埼玉県杉戸町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11464-sugito-machi-2023",
        "citygml": "83923253-7801-461b-837d-ccd9f0ebd274",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11224-toda-shi-2022",
        "city_name": "埼玉県戸田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11224-toda-shi-2022",
        "citygml": "029a8047-3aa9-4eb0-8f7e-eb542f98d394",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11224-toda-shi-2022",
        "city_name": "埼玉県戸田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11224-toda-shi-2022",
        "citygml": "4550fe74-0eee-4d39-8e35-ddb88898a7a4",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-11230-niiza-shi-2020",
        "city_name": "埼玉県新座市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11230-niiza-shi-2020",
        "citygml": "3d7e5f4a-c455-416a-a8a8-d511bdd19486",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11230-niiza-shi-2020",
        "city_name": "埼玉県新座市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11230-niiza-shi-2020",
        "citygml": "6baa1df5-9299-46c7-ab70-3696e89b296c",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-11230-niiza-shi-2020",
        "city_name": "埼玉県新座市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11230-niiza-shi-2020",
        "citygml": "d128f7b5-f361-44dd-b28e-e83943a40837",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-11238-hasuda-shi-2022",
        "city_name": "埼玉県蓮田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11238-hasuda-shi-2022",
        "citygml": "074bc29e-8c44-4710-8b93-4dc076f36f49",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11238-hasuda-shi-2022",
        "city_name": "埼玉県蓮田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11238-hasuda-shi-2022",
        "citygml": "9397dcb6-1441-4eb7-a803-011d1aea95a5",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-11465-matsubushi-machi-2023",
        "city_name": "埼玉県松伏町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11465-matsubushi-machi-2023",
        "citygml": "87cba841-ec0c-416a-81d6-65bf7470b8f7",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11442-miyashiro-machi-2023",
        "city_name": "埼玉県宮代町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11442-miyashiro-machi-2023",
        "citygml": "6ca6ced8-7ed2-463a-ab6d-f83bfd596a36",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11326-moroyama-machi-2020",
        "city_name": "埼玉県毛呂山町市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11326-moroyama-machi-2020",
        "citygml": "a2b10f92-61ff-4125-a1c3-2c23729a6df8",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11326-moroyama-machi-2020",
        "city_name": "埼玉県毛呂山町市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11326-moroyama-machi-2020",
        "citygml": "3beb11f9-be49-4f70-a056-52939e60a0f3",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-11326-moroyama-machi-2020",
        "city_name": "埼玉県毛呂山町市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11326-moroyama-machi-2020",
        "citygml": "ccdb3ff1-d01b-4669-9d55-6b0ad6da4a33",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-11234-yashio-shi-2023",
        "city_name": "埼玉県八潮市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11234-yashio-shi-2023",
        "citygml": "1e3a5abf-f7cb-4805-bade-4052cb3c2948",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-11243-yoshikawa-shi-2023",
        "city_name": "埼玉県吉川市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-11243-yoshikawa-shi-2023",
        "citygml": "0c4c8bd5-31f7-4954-bd2e-8357133fab35",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-12217-kashiwa-shi-2020",
        "city_name": "千葉県柏市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-12217-kashiwa-shi-2020",
        "citygml": "c630ad19-d522-4258-bb66-0538f975f79f",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-12217-kashiwa-shi-2020",
        "city_name": "千葉県柏市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-12217-kashiwa-shi-2020",
        "citygml": "89f7ae55-a4b2-481a-9411-0c7d06f28dc3",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-12217-kashiwa-shi-2020",
        "city_name": "千葉県柏市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-12217-kashiwa-shi-2020",
        "citygml": "44e88796-ba94-43a8-b89a-6f41436b97e0",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-12210-mobara-shi-2022",
        "city_name": "千葉県茂原市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-12210-mobara-shi-2022",
        "citygml": "d10d2140-170b-4bf3-9f3d-1ca230d46d1d",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-12210-mobara-shi-2022",
        "city_name": "千葉県茂原市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-12210-mobara-shi-2022",
        "citygml": "612cd74e-8ed2-41da-ae0c-d176a2322e6a",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-12221-yachiyo-shi-2022",
        "city_name": "千葉県八千代市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-12221-yachiyo-shi-2022",
        "citygml": "4a2a8763-0949-4631-9f1c-4e0315de9794",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-12221-yachiyo-shi-2022",
        "city_name": "千葉県八千代市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-12221-yachiyo-shi-2022",
        "citygml": "f3c84060-a65c-4d25-8d30-f57dbe9aa569",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-13-tokyo-2023",
        "city_name": "東京都（建築モデル等を除く）",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13-tokyo-2023",
        "citygml": "df69f99a-316c-4002-8df4-cadeabc845cf",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-tokyo-takeshiba-2023",
        "city_name": "東京都サンプルデータ（竹芝モデル）",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-tokyo-takeshiba-2023",
        "citygml": "bb74eaa9-82e0-4ce8-8436-e63d24f9b6e6",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13121-adachi-ku-2023",
        "city_name": "東京都足立区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13121-adachi-ku-2023",
        "citygml": "81dd0b8a-6887-4503-9100-1830deb4f4f5",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13118-arakawa-ku-2023",
        "city_name": "東京都荒川区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13118-arakawa-ku-2023",
        "citygml": "ddd63556-5a35-4f7e-8491-6e256c8b833f",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13119-itabashi-ku-2023",
        "city_name": "東京都板橋区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13119-itabashi-ku-2023",
        "citygml": "79944fe9-4136-49cc-a523-702acd3fb8be",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13123-edogawa-ku-2023",
        "city_name": "東京都江戸川区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13123-edogawa-ku-2023",
        "citygml": "0e76b40f-4079-430f-8bbc-ebd3f7db3f4e",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13111-ota-ku-2023",
        "city_name": "東京都大田区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13111-ota-ku-2023",
        "citygml": "e6938a35-1c59-4356-8c99-7e0f9b0b130f",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13122-katsushika-ku-2023",
        "city_name": "東京都葛飾区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13122-katsushika-ku-2023",
        "citygml": "a7c4d15c-7506-40d0-9415-dce3777e1149",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13117-kita-ku-2023",
        "city_name": "東京都北区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13117-kita-ku-2023",
        "citygml": "e18a66fb-ba73-43a6-aea6-f298d5125117",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13108-koto-ku-2023",
        "city_name": "東京都江東区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13108-koto-ku-2023",
        "citygml": "4f9fdef8-2476-4fa4-a346-125185fd7ddc",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13109-shinagawa-ku-2023",
        "city_name": "東京都品川区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13109-shinagawa-ku-2023",
        "citygml": "347f71d4-1add-4fb2-9eb7-2b72baa02357",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13113-shibuya-ku-2023",
        "city_name": "東京都渋谷区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13113-shibuya-ku-2023",
        "citygml": "8bdb5922-33da-4ad1-a5bb-3c38dce8a2a9",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13104-shinjuku-ku-2023",
        "city_name": "東京都新宿区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13104-shinjuku-ku-2023",
        "citygml": "f14a0c18-5818-4a9f-b440-f6ad05258a05",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13115-suginami-ku-2023",
        "city_name": "東京都杉並区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13115-suginami-ku-2023",
        "citygml": "2649f9e1-1f3b-421a-a173-497ebaac3336",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13107-sumida-ku-2023",
        "city_name": "東京都墨田区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13107-sumida-ku-2023",
        "citygml": "cc6303cd-cb33-4ace-8f7b-309178165c87",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13112-setagaya-ku-2023",
        "city_name": "東京都世田谷区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13112-setagaya-ku-2023",
        "citygml": "0ab048eb-9827-4580-9a28-05b6f5df944a",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13106-taito-ku-2023",
        "city_name": "東京都台東区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13106-taito-ku-2023",
        "citygml": "d2000818-d1fc-464a-acf8-79d63eaa1a40",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13102-chuo-ku-2023",
        "city_name": "東京都中央区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13102-chuo-ku-2023",
        "citygml": "e6b6dd4a-0024-44b4-b363-0771f80b7532",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13101-chiyoda-ku-2023",
        "city_name": "東京都千代田区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13101-chiyoda-ku-2023",
        "citygml": "2d2bcfee-467e-4518-b448-a9af101406f3",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13116-toshima-ku-2023",
        "city_name": "東京都豊島区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13116-toshima-ku-2023",
        "citygml": "269b5300-0214-4a7b-a8b0-8bcef1102d53",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13114-nakano-ku-2023",
        "city_name": "東京都中野区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13114-nakano-ku-2023",
        "citygml": "afedefb6-24c0-46e8-a40b-b41c8ab42c94",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13120-nerima-ku-2023",
        "city_name": "東京都練馬区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13120-nerima-ku-2023",
        "citygml": "1ec97ca4-b3eb-4aaa-b8fc-7fa5bd02eee0",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13105-bunkyo-ku-2023",
        "city_name": "東京都文京区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13105-bunkyo-ku-2023",
        "citygml": "91a0bba3-338d-4b53-a11a-ff01dc50bdff",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13103-minato-ku-2023",
        "city_name": "東京都港区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13103-minato-ku-2023",
        "citygml": "77a9468d-9edb-4243-be84-e81fbfe4fe98",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13110-meguro-ku-2023",
        "city_name": "東京都目黒区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13110-meguro-ku-2023",
        "citygml": "fb2aac54-e88c-43b1-b20d-74a983c9c24f",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13207-akishima-shi-2023",
        "city_name": "東京都昭島市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13207-akishima-shi-2023",
        "citygml": "172c979f-855a-4900-b99b-6520dc56aeeb",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13228-akiruno-shi-2023",
        "city_name": "東京都あきる野市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13228-akiruno-shi-2023",
        "citygml": "e39763b3-384c-4833-8512-568ef807bf4a",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13308-okutama-machi-2023",
        "city_name": "東京都奥多摩町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13308-okutama-machi-2023",
        "citygml": "8c6c1e12-2694-480f-8e8c-013aa64eb40e",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13205-ome-shi-2023",
        "city_name": "東京都青梅市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13205-ome-shi-2023",
        "citygml": "e6190930-8304-422d-b23a-d9aed82c3a31",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13221-kiyose-shi-2023",
        "city_name": "東京都清瀬市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13221-kiyose-shi-2023",
        "citygml": "f373754e-a691-443a-84b6-0a5c849315bc",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13215-kunitachi-shi-2023",
        "city_name": "東京都国立市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13215-kunitachi-shi-2023",
        "citygml": "178d90e0-8e86-455b-8be2-ff9f7e61536e",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13210-koganei-shi-2023",
        "city_name": "東京都小金井市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13210-koganei-shi-2023",
        "citygml": "6edc4d35-8910-42cb-9d7f-6181ce61f7c1",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13214-kokubunji-shi-2023",
        "city_name": "東京都国分寺市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13214-kokubunji-shi-2023",
        "citygml": "26293e77-91a9-4d0d-b810-beafdf9eadb0",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13211-kodaira-shi-2023",
        "city_name": "東京都小平市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13211-kodaira-shi-2023",
        "citygml": "7b8dc96b-8df8-4104-b599-0baefb9db050",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13219-komae-shi-2023",
        "city_name": "東京都狛江市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13219-komae-shi-2023",
        "citygml": "769f917d-b7e6-42bd-b5bf-29db91ff9495",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13202-tachikawa-shi-2023",
        "city_name": "東京都立川市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13202-tachikawa-shi-2023",
        "citygml": "4e8115ad-4709-4cfa-b75c-232d3b74cc9f",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13224-tama-shi-2023",
        "city_name": "東京都多摩市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13224-tama-shi-2023",
        "citygml": "06bce078-b923-450e-8509-a700857b239c",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13208-chofu-shi-2023",
        "city_name": "東京都調布市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13208-chofu-shi-2023",
        "citygml": "8099ddfa-5cbb-493d-8e46-15b71ea19120",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13229-nishitokyo-shi-2022",
        "city_name": "東京都西東京市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13229-nishitokyo-shi-2022",
        "citygml": "7b9c2815-e739-4a3d-88cb-66b26106d60b",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-13229-nishitokyo-shi-2023",
        "city_name": "東京都西東京市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13229-nishitokyo-shi-2023",
        "citygml": "22d4cb46-959f-4574-813c-4f2441c1ca62",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13201-hachioji-shi-2020",
        "city_name": "東京都八王子市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13201-hachioji-shi-2020",
        "citygml": "4c4fb49e-fcd5-43de-87a1-835aeec0a164",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-13201-hachioji-shi-2020",
        "city_name": "東京都八王子市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13201-hachioji-shi-2020",
        "citygml": "d2d7496e-0997-405c-a785-0e89eb4a1a8b",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-13201-hachioji-shi-2022",
        "city_name": "東京都八王子市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13201-hachioji-shi-2022",
        "citygml": "ef7d1a60-334d-44c6-98c8-e8409779e889",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-13201-hachioji-shi-2023",
        "city_name": "東京都八王子市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13201-hachioji-shi-2023",
        "citygml": "3cdcc511-5bc0-45a2-ac50-7df9582da7df",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13227-hamura-shi-2023",
        "city_name": "東京都羽村市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13227-hamura-shi-2023",
        "citygml": "48faeba2-0cbc-4b32-a716-5ef56bff1b0a",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13222-higashikurume-shi-2023",
        "city_name": "東京都東久留米市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13222-higashikurume-shi-2023",
        "citygml": "aee0b6ca-ce04-4aa3-86f1-129996c4958a",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13213-higashimurayama-shi-2020",
        "city_name": "東京都東村山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13213-higashimurayama-shi-2020",
        "citygml": "4b3120d2-4bb2-4d00-ab0f-236219189c7f",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-13213-higashimurayama-shi-2020",
        "city_name": "東京都東村山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13213-higashimurayama-shi-2020",
        "citygml": "4877a936-c244-468f-8bb1-3d3bfa606528",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-13213-higashimurayama-shi-2023",
        "city_name": "東京都東村山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13213-higashimurayama-shi-2023",
        "citygml": "588be08b-f5dd-46b6-94e4-1ec97dcfaf2a",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13220-higashiyamato-shi-2023",
        "city_name": "東京都東大和市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13220-higashiyamato-shi-2023",
        "citygml": "3c5e21ff-5df8-4d62-8ce9-0c8a429f525f",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13212-hino-shi-2023",
        "city_name": "東京都日野市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13212-hino-shi-2023",
        "citygml": "9bb37ac6-e762-47e6-89ac-6c40f0e679ea",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13305-hinode-machi-2023",
        "city_name": "東京都日の出町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13305-hinode-machi-2023",
        "citygml": "df547c09-365f-42d4-9326-a2c74de576e9",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13307-hinohara-mura-2023",
        "city_name": "東京都檜原村",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13307-hinohara-mura-2023",
        "citygml": "b8e37917-e5aa-484c-9c54-2d710d51ccbe",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13218-fussa-shi-2023",
        "city_name": "東京都福生市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13218-fussa-shi-2023",
        "citygml": "10fcbe84-acdf-4bdf-8233-fb75e30a092d",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13206-fuchu-shi-2023",
        "city_name": "東京都府中市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13206-fuchu-shi-2023",
        "citygml": "e9a3282a-4222-4e94-87be-006e6e268e3b",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13209-machida-shi-2023",
        "city_name": "東京都町田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13209-machida-shi-2023",
        "citygml": "107eebfe-1d68-42cc-93de-801f9bd8def1",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13303-mizuho-machi-2023",
        "city_name": "東京都瑞穂町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13303-mizuho-machi-2023",
        "citygml": "571e9f81-45ed-4100-a6e1-098f9af58a26",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13204-mitaka-shi-2023",
        "city_name": "東京都三鷹市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13204-mitaka-shi-2023",
        "citygml": "8331dd75-3b51-434d-9d0a-7bfa813c1723",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13203-musashino-shi-2023",
        "city_name": "東京都武蔵野市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13203-musashino-shi-2023",
        "citygml": "2af06cda-b978-4aaf-8064-8b8afbf084b8",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-13223-musashimurayama-shi-2023",
        "city_name": "東京都武蔵村山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-13223-musashimurayama-shi-2023",
        "citygml": "2c0e2c08-5638-4192-abf9-a74b788a9110",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-tokyo23ku",
        "city_name": "東京都23区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-tokyo23ku",
        "citygml": "e9d2373d-0fd4-4efe-866a-52036b38eaa9",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-tokyo23ku",
        "city_name": "東京都23区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-tokyo23ku",
        "citygml": "0bab2b7f-6962-41c8-872f-66ad9b40dcb1",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-tokyo23ku-2022",
        "city_name": "東京都23区",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-tokyo23ku-2022",
        "citygml": "55c72dd0-32eb-4107-9526-71fc0af8d50f",
        "spec": "2",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-14212-atsugi-shi-2023",
        "city_name": "神奈川県厚木市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14212-atsugi-shi-2023",
        "citygml": "a1966d18-41e3-47d7-a2b5-6bc47cea9109",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-14130-kawasaki-shi-2020",
        "city_name": "神奈川県川崎市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14130-kawasaki-shi-2020",
        "citygml": "b334361b-76a9-4ead-bf03-5821d49a3566",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-14130-kawasaki-shi-2020",
        "city_name": "神奈川県川崎市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14130-kawasaki-shi-2020",
        "citygml": "51a8a702-03ee-45db-9136-3881daba2477",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-14130-kawasaki-shi-2022",
        "city_name": "神奈川県川崎市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14130-kawasaki-shi-2022",
        "citygml": "b3e9ba6b-0056-4373-be85-f00d37525465",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-14130-kawasaki-shi-2022",
        "city_name": "神奈川県川崎市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14130-kawasaki-shi-2022",
        "citygml": "17d4084d-9fed-4194-bc1c-37de9f2a9c7a",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-14150-sagamihara-shi-2020",
        "city_name": "神奈川県相模原市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14150-sagamihara-shi-2020",
        "citygml": "5a615e76-ad73-4492-87d6-b192fd92379b",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-14150-sagamihara-shi-2020",
        "city_name": "神奈川県相模原市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14150-sagamihara-shi-2020",
        "citygml": "b910d62c-6a89-4b91-aaec-8a7596432139",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-14150-sagamihara-shi-2023",
        "city_name": "神奈川県相模原市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14150-sagamihara-shi-2023",
        "citygml": "ea34cf72-ffe0-44d5-b6e7-f417cbc03ebd",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-14382-hakone-machi-2020",
        "city_name": "神奈川県箱根町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14382-hakone-machi-2020",
        "citygml": "50ae5ffd-e969-4061-82b3-407b158b55e5",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-14382-hakone-machi-2020",
        "city_name": "神奈川県箱根町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14382-hakone-machi-2020",
        "citygml": "e9d9ccc1-e52e-4988-a690-e83d3960bfab",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-14382-hakone-machi-2020",
        "city_name": "神奈川県箱根町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14382-hakone-machi-2020",
        "citygml": "d2a7c149-6519-40a6-a06d-9b6512304b23",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-14201-yokosuka-shi-2020",
        "city_name": "神奈川県横須賀市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14201-yokosuka-shi-2020",
        "citygml": "73b61814-abed-4add-b209-2f511e4f5af2",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-14201-yokosuka-shi-2020",
        "city_name": "神奈川県横須賀市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14201-yokosuka-shi-2020",
        "citygml": "d5153b9b-a3f0-4024-9cc4-86a3a4200079",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-14201-yokosuka-shi-2020",
        "city_name": "神奈川県横須賀市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14201-yokosuka-shi-2020",
        "citygml": "31c6a382-f922-42d7-85e0-26ab2c6655ca",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-14100-yokohama-city-2020",
        "city_name": "神奈川県横浜市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14100-yokohama-city-2020",
        "citygml": "087832f6-a7d4-4f07-858b-ec9baeecacc2",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-14100-yokohama-city-2020",
        "city_name": "神奈川県横浜市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14100-yokohama-city-2020",
        "citygml": "ef70f915-2347-4b50-9008-46a6027bda4b",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-14100-yokohama-shi-2022",
        "city_name": "神奈川県横浜市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14100-yokohama-shi-2022",
        "citygml": "f4ba72a5-d693-4947-a6ed-547ca346c3c1",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-14100-yokohama-shi-2023",
        "city_name": "神奈川県横浜市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-14100-yokohama-shi-2023",
        "citygml": "c25e4a30-e7f4-4222-8c0e-e593e149e8db",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-15222-joetsu-shi-2023",
        "city_name": "新潟県上越市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-15222-joetsu-shi-2023",
        "citygml": "024e0fdd-c8b8-4f00-9c9d-dfd9b1f57897",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-15202-nagaoka-shi-2023",
        "city_name": "新潟県長岡市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-15202-nagaoka-shi-2023",
        "citygml": "321d5fa2-1fe6-4e3d-9177-5127000a761c",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-15100-niigata-shi-2020",
        "city_name": "新潟県新潟市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-15100-niigata-shi-2020",
        "citygml": "439948b4-a38b-4932-917d-fe8e82a61934",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-15100-niigata-shi-2020",
        "city_name": "新潟県新潟市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-15100-niigata-shi-2020",
        "citygml": "1ecc0b56-f9ab-4ab9-b70e-691698a9e4ee",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-15100-niigata-shi-2022",
        "city_name": "新潟県新潟市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-15100-niigata-shi-2022",
        "citygml": "0b0d7ed2-ed57-41f4-b481-11e0454c71a9",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-15100-niigata-shi-2023",
        "city_name": "新潟県新潟市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-15100-niigata-shi-2023",
        "citygml": "6310d665-3c85-4bd4-82a7-433a3afd217f",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-17206-kaga-shi-2020",
        "city_name": "石川県加賀市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-17206-kaga-shi-2020",
        "citygml": "bf13fbef-e717-446d-a325-25f229e5248d",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-17206-kaga-shi-2021",
        "city_name": "石川県加賀市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-17206-kaga-shi-2021",
        "citygml": "50b61a19-e6bd-437d-9cc1-88eb7042af78",
        "spec": "2",
        "version": "2021",
    },
    {
        "dataset_id": "plateau-17206-kaga-shi-2021",
        "city_name": "石川県加賀市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-17206-kaga-shi-2021",
        "citygml": "09bd9068-96ce-4315-9e15-a3f3d08433c5",
        "spec": "1",
        "version": "2021",
    },
    {
        "dataset_id": "plateau-17206-kaga-shi-2022",
        "city_name": "石川県加賀市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-17206-kaga-shi-2022",
        "citygml": "007db2ed-6dc3-44d6-ad53-816e89f77e3a",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-17206-kaga-shi-2022",
        "city_name": "石川県加賀市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-17206-kaga-shi-2022",
        "citygml": "dea2a59d-dede-42b9-bc4a-ed270eb3cdc4",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-17201-kanazawa-shi-2020",
        "city_name": "石川県金沢市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-17201-kanazawa-shi-2020",
        "citygml": "207f746c-2639-41f8-abb5-3ec4fe6ced44",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-17201-kanazawa-shi-2020",
        "city_name": "石川県金沢市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-17201-kanazawa-shi-2020",
        "citygml": "87b8b2de-fd92-4710-9f88-d6ccd8693be1",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-17201-kanazawa-shi-2023",
        "city_name": "石川県金沢市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-17201-kanazawa-shi-2023",
        "citygml": "93a48e8a-b49d-4396-8431-b3fd8f20b8b4",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-20209-ina-shi-2020",
        "city_name": "長野県伊那市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20209-ina-shi-2020",
        "citygml": "572d4fee-29e6-4f8a-a16a-d713a56337ef",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-20209-ina-shi-2020",
        "city_name": "長野県伊那市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20209-ina-shi-2020",
        "citygml": "b1c9ce1f-4142-4334-80a2-5245fce32de3",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-20209-ina-shi-2020",
        "city_name": "長野県伊那市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20209-ina-shi-2020",
        "citygml": "fbaaced1-a87b-405a-aef5-ce1b36e812d8",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-20204-okaya-shi-2020",
        "city_name": "長野県岡谷市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20204-okaya-shi-2020",
        "citygml": "9331c8d2-de7d-4e09-9e84-0bc6bd12e0e4",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-20204-okaya-shi-2020",
        "city_name": "長野県岡谷市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20204-okaya-shi-2020",
        "citygml": "fbd57aeb-6832-48d1-b5e1-163371d3de2b",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-20204-okaya-shi-2022",
        "city_name": "長野県岡谷市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20204-okaya-shi-2022",
        "citygml": "88cb963b-91a9-40eb-b8f0-102a6a9ac171",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-20204-okaya-shi-2022",
        "city_name": "長野県岡谷市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20204-okaya-shi-2022",
        "citygml": "59775dd6-0d4b-468a-9581-5c995a5e8bda",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-20217-saku-shi-2022",
        "city_name": "長野県佐久市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20217-saku-shi-2022",
        "citygml": "d96f29a5-5a0f-495b-a1d7-6de92b4b3df6",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-20217-saku-shi-2022",
        "city_name": "長野県佐久市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20217-saku-shi-2022",
        "citygml": "6bcf4ae5-86ce-4228-be3c-2f26652102f0",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-20206-suwa-shi-2023",
        "city_name": "長野県諏訪市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20206-suwa-shi-2023",
        "citygml": "8db62475-7982-4257-9bcd-16af690fd750",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-20214-chino-shi-2020",
        "city_name": "長野県茅野市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20214-chino-shi-2020",
        "citygml": "dfe793bb-ed77-452b-bac5-afe731647f6a",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-20214-chino-shi-2020",
        "city_name": "長野県茅野市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20214-chino-shi-2020",
        "citygml": "3755ab32-a73d-429d-8583-869850c6053c",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-20214-chino-shi-2022",
        "city_name": "長野県茅野市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20214-chino-shi-2022",
        "citygml": "45ce6f76-5564-4799-8352-e6e8a7398d03",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-20214-chino-shi-2023",
        "city_name": "長野県茅野市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20214-chino-shi-2023",
        "citygml": "be24573a-6d1d-4a50-9435-e55552c3b2c0",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-20202-matsumoto-shi-2020",
        "city_name": "長野県松本市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20202-matsumoto-shi-2020",
        "citygml": "ed380da2-6f51-463a-a11e-a0e446438761",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-20202-matsumoto-shi-2020",
        "city_name": "長野県松本市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20202-matsumoto-shi-2020",
        "citygml": "7aadf034-243e-4b59-a911-36bf4628fc53",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-20202-matsumoto-shi-2020",
        "city_name": "長野県松本市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-20202-matsumoto-shi-2020",
        "citygml": "40591402-8363-4512-88ac-3d191a806e8d",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-21201-gifu-shi-2020",
        "city_name": "岐阜県岐阜市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-21201-gifu-shi-2020",
        "citygml": "8953ab80-5ed0-465a-b9d8-3dc9c1dd6739",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-21201-gifu-shi-2020",
        "city_name": "岐阜県岐阜市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-21201-gifu-shi-2020",
        "citygml": "a8f0da53-862a-4116-a53f-f81690a38d5c",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-21201-gifu-shi-2022",
        "city_name": "岐阜県岐阜市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-21201-gifu-shi-2022",
        "citygml": "08e8f100-7827-4cfa-82e6-f4c8a9665793",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-21201-gifu-shi-2023",
        "city_name": "岐阜県岐阜市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-21201-gifu-shi-2023",
        "citygml": "25434c56-4402-4b12-87eb-cff49586bc9d",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-21211-minokamo-shi-2022",
        "city_name": "岐阜県美濃加茂市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-21211-minokamo-shi-2022",
        "citygml": "f52cf383-bc5e-44b9-a938-309a8ab7db17",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-21211-minokamo-shi-2022",
        "city_name": "岐阜県美濃加茂市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-21211-minokamo-shi-2022",
        "citygml": "3825d2f6-e1de-4e69-bda5-1621aeda2af3",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-19201-kofu-shi-2022",
        "city_name": "山梨県甲府市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-19201-kofu-shi-2022",
        "citygml": "8931fbf1-1873-4406-84da-85f2b1187fd6",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-19201-kofu-shi-2023",
        "city_name": "山梨県甲府市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-19201-kofu-shi-2023",
        "citygml": "74f8535d-f739-4fa0-ab60-d62a812759d5",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22205-atami-shi-2022",
        "city_name": "静岡県熱海市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22205-atami-shi-2022",
        "citygml": "23c6f893-209f-4ebd-a4be-8a8310f85396",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22205-atami-shi-2023",
        "city_name": "静岡県熱海市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22205-atami-shi-2023",
        "citygml": "f70118b4-165e-4d87-b4d1-6b6fb871851f",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22222-izu-shi-2022",
        "city_name": "静岡県伊豆市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22222-izu-shi-2022",
        "citygml": "f1b756f2-ccce-4e05-a67e-43d542d7613b",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22222-izu-shi-2023",
        "city_name": "静岡県伊豆市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22222-izu-shi-2023",
        "citygml": "770c371f-179b-454e-8509-95374fa872f7",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22225-izunokuni-shi-2022",
        "city_name": "静岡県伊豆の国市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22225-izunokuni-shi-2022",
        "citygml": "db3e4121-9342-4d6e-89ac-4cc376501374",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22225-izunokuni-shi-2023",
        "city_name": "静岡県伊豆の国市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22225-izunokuni-shi-2023",
        "citygml": "1cbbd3ec-ac76-4f02-b2a6-3579b0c78e4d",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22208-ito-shi-2022",
        "city_name": "静岡県伊東市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22208-ito-shi-2022",
        "citygml": "6f4a97b6-64b6-474d-b28c-c8fb98d36937",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22208-ito-shi-2023",
        "city_name": "静岡県伊東市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22208-ito-shi-2023",
        "citygml": "263a02fa-2720-4f45-8221-97c08f81f31e",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22211-iwata-shi-2022",
        "city_name": "静岡県磐田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22211-iwata-shi-2022",
        "citygml": "3f9a656b-36b1-4d0f-b4e2-3a9da72d6c30",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22211-iwata-shi-2023",
        "city_name": "静岡県磐田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22211-iwata-shi-2023",
        "citygml": "582f1591-f0de-4724-8c1c-91edc826ac35",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22223-omaezaki-shi-2022",
        "city_name": "静岡県御前崎市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22223-omaezaki-shi-2022",
        "citygml": "0778768e-f2cd-4e67-b298-98a87188f360",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22223-omaezaki-shi-2023",
        "city_name": "静岡県御前崎市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22223-omaezaki-shi-2023",
        "citygml": "518218d9-d68f-4eb0-a1de-bf8c67fd4ae9",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22344-oyama-cho-2022",
        "city_name": "静岡県小山町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22344-oyama-cho-2022",
        "citygml": "f1a32827-15d1-4f3a-b130-23bc3a26c651",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22344-oyama-cho-2023",
        "city_name": "静岡県小山町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22344-oyama-cho-2023",
        "citygml": "36ce0cb6-dbb4-4fdf-91a6-11746561accd",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22213-kakegawa-shi-2020",
        "city_name": "静岡県掛川市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22213-kakegawa-shi-2020",
        "citygml": "d579f9d0-e0c2-4d1c-a7f0-771885802ce1",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-22213-kakegawa-shi-2020",
        "city_name": "静岡県掛川市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22213-kakegawa-shi-2020",
        "citygml": "b6690396-44f5-46e4-90b2-9ba5ab00a388",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-22213-kakegawa-shi-2023",
        "city_name": "静岡県掛川市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22213-kakegawa-shi-2023",
        "citygml": "ed611fef-ceee-43a2-8af4-a726e2f5249e",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22302-kawazu-cho-2022",
        "city_name": "静岡県河津町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22302-kawazu-cho-2022",
        "citygml": "02f2902f-e400-448d-8388-ddc5dcf1768b",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22302-kawazu-cho-2023",
        "city_name": "静岡県河津町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22302-kawazu-cho-2023",
        "citygml": "7fdc6a06-759e-46e1-8c43-16256e114b9b",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22429-kawanehon-cho-2023",
        "city_name": "静岡県川根本町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22429-kawanehon-cho-2023",
        "citygml": "34781e93-9461-42e7-97bc-6f80f9b1a69a",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22325-kannami-cho-2022",
        "city_name": "静岡県函南町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22325-kannami-cho-2022",
        "citygml": "53c7d344-c261-42b6-88d2-4ad32efd4c44",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22325-kannami-cho-2023",
        "city_name": "静岡県函南町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22325-kannami-cho-2023",
        "citygml": "06b2b15b-a056-4a5a-aeb2-eb0e5e1b7ee1",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22224-kikugawa-city-2020",
        "city_name": "静岡県菊川市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22224-kikugawa-city-2020",
        "citygml": "2f0d604b-3880-44af-b516-4035786817b2",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-22224-kikugawa-city-2020",
        "city_name": "静岡県菊川市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22224-kikugawa-city-2020",
        "citygml": "f2a8c891-73ff-40f8-a88a-d1415e5a8725",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-22224-kikugawa-shi-2023",
        "city_name": "静岡県菊川市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22224-kikugawa-shi-2023",
        "citygml": "92a9ded0-548d-4f26-892d-3fe273837737",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22221-kosai-shi-2022",
        "city_name": "静岡県湖西市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22221-kosai-shi-2022",
        "citygml": "1c61303d-eebc-4699-9e96-519b38fee92f",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22221-kosai-shi-2023",
        "city_name": "静岡県湖西市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22221-kosai-shi-2023",
        "citygml": "4ffd9368-1373-4a5d-93d2-afdd7efb5e10",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22215-gotenba-shi-2022",
        "city_name": "静岡県御殿場市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22215-gotenba-shi-2022",
        "citygml": "f2187864-6d63-499e-a526-76dcbd2413a7",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22215-gotenba-shi-2023",
        "city_name": "静岡県御殿場市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22215-gotenba-shi-2023",
        "citygml": "4d317d09-4b22-4de6-bd3b-b866b249b721",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22100-shizuoka-shi-2022",
        "city_name": "静岡県静岡市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22100-shizuoka-shi-2022",
        "citygml": "6f0e8388-0dfe-4fcb-aadf-9f41cd26df65",
        "spec": "2",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22209-shimada-shi-2023",
        "city_name": "静岡県島田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22209-shimada-shi-2023",
        "citygml": "29d69863-aaa3-4c40-a37c-cc3bbd03e4b8",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22341-shimizu-cho-2022",
        "city_name": "静岡県清水町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22341-shimizu-cho-2022",
        "citygml": "f03efa32-d0ce-4689-932f-c88141849bac",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22341-shimizu-cho-2023",
        "city_name": "静岡県清水町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22341-shimizu-cho-2023",
        "citygml": "e791c265-48f3-4f4b-8352-f18184cdfcdd",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22219-shimoda-shi-2022",
        "city_name": "静岡県下田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22219-shimoda-shi-2022",
        "citygml": "fda8a9e7-9443-4b0a-87c8-ce963f7eb716",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22219-shimoda-shi-2023",
        "city_name": "静岡県下田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22219-shimoda-shi-2023",
        "citygml": "f5634eb0-0cba-4cb2-9315-a894f47c5ca6",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22220-susono-shi-2022",
        "city_name": "静岡県裾野市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22220-susono-shi-2022",
        "citygml": "7e21dc08-7651-4a5f-95c2-b4ddc30034e0",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22220-susono-shi-2023",
        "city_name": "静岡県裾野市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22220-susono-shi-2023",
        "citygml": "69f4a44f-bfc0-4f08-b529-99344043891e",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22342-nagaizumi-cho-2022",
        "city_name": "静岡県長泉町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22342-nagaizumi-cho-2022",
        "citygml": "7fea2135-bdee-40d2-811e-6c1c7e9eca2a",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22342-nagaizumi-cho-2023",
        "city_name": "静岡県長泉町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22342-nagaizumi-cho-2023",
        "citygml": "6e5dfc34-71b2-4cfe-9e46-38a3617923d1",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22306-nishiizu-cho-2023",
        "city_name": "静岡県西伊豆町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22306-nishiizu-cho-2023",
        "citygml": "528ea721-292c-45ae-b2ea-4006fd89b89b",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22203-numazu-shi-2020",
        "city_name": "静岡県沼津市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22203-numazu-shi-2020",
        "citygml": "71b80915-1c17-4975-a8f2-c69871cee1f5",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-22203-numazu-shi-2021",
        "city_name": "静岡県沼津市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22203-numazu-shi-2021",
        "citygml": "758fe63a-b20f-4d5d-817d-c35eac530143",
        "spec": "2",
        "version": "2021",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22203-numazu-shi-2021",
        "city_name": "静岡県沼津市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22203-numazu-shi-2021",
        "citygml": "ec95589f-943d-4ce2-9795-de11953312a4",
        "spec": "1",
        "version": "2021",
    },
    {
        "dataset_id": "plateau-22130-hamamatsu-shi-2023",
        "city_name": "静岡県浜松市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22130-hamamatsu-shi-2023",
        "citygml": "4f92750f-561d-4678-b22b-7a51139500aa",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22130-hamamatsu-shi-2022",
        "city_name": "静岡県浜松市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22130-hamamatsu-shi-2022",
        "citygml": "a838fa43-3011-4460-bb64-2429a7522ba3",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22301-higashiizu-cho-2022",
        "city_name": "静岡県東伊豆町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22301-higashiizu-cho-2022",
        "citygml": "407f7b68-0b25-407a-96b8-de176f746e94",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22301-higashiizu-cho-2023",
        "city_name": "静岡県東伊豆町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22301-higashiizu-cho-2023",
        "citygml": "af16503e-ef28-4985-b7ab-f430ecae9ec8",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22216-fukuroi-shi-2022",
        "city_name": "静岡県袋井市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22216-fukuroi-shi-2022",
        "citygml": "864d2ca4-045f-490e-ba05-abcbceaeed5d",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22216-fukuroi-shi-2023",
        "city_name": "静岡県袋井市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22216-fukuroi-shi-2023",
        "citygml": "b2442d23-b3a6-4d9d-9396-af07a6cd0796",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22210-fuji-shi-2022",
        "city_name": "静岡県富士市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22210-fuji-shi-2022",
        "citygml": "00da73ef-4aa5-4a04-bd39-ee6bc96a87bd",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22210-fuji-shi-2023",
        "city_name": "静岡県富士市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22210-fuji-shi-2023",
        "citygml": "499fbd71-5a95-42e7-b8b8-14bee9d08462",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22214-fujieda-shi-2022",
        "city_name": "静岡県藤枝市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22214-fujieda-shi-2022",
        "citygml": "0967b2b0-f23b-4d25-85d6-cdc33f2c6b5e",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22214-fujieda-shi-2023",
        "city_name": "静岡県藤枝市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22214-fujieda-shi-2023",
        "citygml": "bcd417df-e448-4ce5-b391-09c53ca75264",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22207-fujinomiya-shi-2022",
        "city_name": "静岡県富士宮市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22207-fujinomiya-shi-2022",
        "citygml": "75aa2464-afea-44ae-abeb-bc6779895b7f",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22207-fujinomiya-shi-2023",
        "city_name": "静岡県富士宮市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22207-fujinomiya-shi-2023",
        "citygml": "91b3f35b-d96f-430e-b72f-c34866403374",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22226-makinohara-shi-2022",
        "city_name": "静岡県牧之原市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22226-makinohara-shi-2022",
        "citygml": "3958611b-2ad3-4ce0-a21f-ea78fce3556c",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22226-makinohara-shi-2023",
        "city_name": "静岡県牧之原市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22226-makinohara-shi-2023",
        "citygml": "f9aa2dd4-757b-46bb-8031-86e8a61f7ae7",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22305-matsuzaki-cho-2023",
        "city_name": "静岡県松崎町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22305-matsuzaki-cho-2023",
        "citygml": "b5e11757-d668-4402-ab4f-523620dc97c1",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22206-mishima-shi-2022",
        "city_name": "静岡県三島市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22206-mishima-shi-2022",
        "citygml": "85ec9a31-5960-433e-b352-55928cc63480",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22206-mishima-shi-2023",
        "city_name": "静岡県三島市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22206-mishima-shi-2023",
        "citygml": "4d9bd7e4-8c04-4f9b-b350-9e2b57ad0bdd",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22304-minamiizu-cho-2022",
        "city_name": "静岡県南伊豆町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22304-minamiizu-cho-2022",
        "citygml": "05d34943-457e-46c7-a890-a729e4658916",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22304-minamiizu-cho-2023",
        "city_name": "静岡県南伊豆町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22304-minamiizu-cho-2023",
        "citygml": "c7e68c7d-4a4b-43c5-803a-94fe7b74bcf3",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22461-mori-machi-2022",
        "city_name": "静岡県森町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22461-mori-machi-2022",
        "citygml": "943ccee9-6b92-45d9-b288-f2f3d3dd31ac",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22461-mori-machi-2023",
        "city_name": "静岡県森町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22461-mori-machi-2023",
        "citygml": "d9f8fee6-651e-4ad1-ba29-9a6851dfd519",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22212-yaizu-shi-2022",
        "city_name": "静岡県焼津市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22212-yaizu-shi-2022",
        "citygml": "da88169b-3763-4065-9191-f75f6cb03726",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22212-yaizu-shi-2023",
        "city_name": "静岡県焼津市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22212-yaizu-shi-2023",
        "citygml": "0bdf8ef5-1d33-4144-b0a5-097de90e7e73",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-22424-yoshida-cho-2022",
        "city_name": "静岡県吉田町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22424-yoshida-cho-2022",
        "citygml": "8d07cf7e-9fdb-4f4c-848c-77c62bcca52d",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-22424-yoshida-cho-2023",
        "city_name": "静岡県吉田町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-22424-yoshida-cho-2023",
        "citygml": "40ca0aeb-b7c4-46d8-8fb4-d8d88a4520fa",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-23212-anjo-shi-2020",
        "city_name": "愛知県安城市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23212-anjo-shi-2020",
        "citygml": "69fad0b5-9671-449a-a68b-70a07359c4cc",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-23212-anjo-shi-2020",
        "city_name": "愛知県安城市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23212-anjo-shi-2020",
        "citygml": "2f3b2351-e7fd-4553-bd00-1424bb05964b",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-23212-anjo-shi-2020",
        "city_name": "愛知県安城市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23212-anjo-shi-2020",
        "citygml": "7f8a22d1-652b-4290-badc-ae0f931c6b18",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-23202-okazaki-shi-2020",
        "city_name": "愛知県岡崎市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23202-okazaki-shi-2020",
        "citygml": "e9ce1050-66a0-4e99-8102-866a905b631d",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-23202-okazaki-shi-2020",
        "city_name": "愛知県岡崎市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23202-okazaki-shi-2020",
        "citygml": "1ee7a7cf-8171-4d6f-be21-a2f268b17298",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-23202-okazaki-shi-2020",
        "city_name": "愛知県岡崎市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23202-okazaki-shi-2020",
        "citygml": "481fde81-ee89-4e1d-a26e-44ec2719d46d",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-23206-kasugai-shi-2022",
        "city_name": "愛知県春日井市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23206-kasugai-shi-2022",
        "citygml": "199e5bdd-4a2d-479c-8f1a-7d4d75770c10",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-23206-kasugai-shi-2023",
        "city_name": "愛知県春日井市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23206-kasugai-shi-2023",
        "citygml": "a503b995-e173-4327-a93b-85aef02a92b9",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-23208-tsushima-shi-2020",
        "city_name": "愛知県津島市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23208-tsushima-shi-2020",
        "citygml": "945e6660-ee2c-42dd-aecd-fe5ead25a4a6",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-23208-tsushima-shi-2020",
        "city_name": "愛知県津島市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23208-tsushima-shi-2020",
        "citygml": "8bcfa8c2-8b75-4813-abdd-0803353baaa8",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-23208-tsushima-shi-2020",
        "city_name": "愛知県津島市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23208-tsushima-shi-2020",
        "citygml": "18613a1d-16eb-4aa5-aaff-08a40d1aab8b",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-23207-toyokawa-shi-2022",
        "city_name": "愛知県豊川市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23207-toyokawa-shi-2022",
        "citygml": "cd9ca5d2-d349-44b9-a23c-e976b898aac8",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-23207-toyokawa-shi-2022",
        "city_name": "愛知県豊川市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23207-toyokawa-shi-2022",
        "citygml": "809deb42-c22d-498c-afd9-be2249730899",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-23211-toyota-shi-2023",
        "city_name": "愛知県豊田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23211-toyota-shi-2023",
        "citygml": "66272b2d-38c2-4420-83eb-4334cddb9361",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-23201-toyohashi-shi-2023",
        "city_name": "愛知県豊橋市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23201-toyohashi-shi-2023",
        "citygml": "cea56c78-822b-4aa0-8e08-8745d9410c66",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-23100-nagoya-shi-2020",
        "city_name": "愛知県名古屋市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23100-nagoya-shi-2020",
        "citygml": "cfe05e59-1e23-4646-8948-8e573d3ca992",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-23100-nagoya-shi-2020",
        "city_name": "愛知県名古屋市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23100-nagoya-shi-2020",
        "citygml": "718bf496-7da7-4b7f-83c3-98dd4a8e3acb",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-23100-nagoya-shi-2022",
        "city_name": "愛知県名古屋市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23100-nagoya-shi-2022",
        "citygml": "0b568d5a-2e26-40be-be68-d39cee3b4672",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-23230-nisshin-shi-2022",
        "city_name": "愛知県日進市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23230-nisshin-shi-2022",
        "citygml": "cee5a327-2a72-43ba-935d-4a4bedd86097",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-23230-nisshin-shi-2023",
        "city_name": "愛知県日進市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-23230-nisshin-shi-2023",
        "citygml": "fb42224d-3ed5-4c11-885d-668247244db1",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-24212-kumano-shi-2022",
        "city_name": "三重県熊野市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-24212-kumano-shi-2022",
        "citygml": "0192d301-7242-4776-8eec-68971880940d",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-24212-kumano-shi-2022",
        "city_name": "三重県熊野市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-24212-kumano-shi-2022",
        "citygml": "a63fbbf5-ab09-40d7-9893-31280ee09386",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-24202-yokkaichi-shi-2022",
        "city_name": "三重県四日市市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-24202-yokkaichi-shi-2022",
        "citygml": "a8bdf287-c837-4fb0-9263-d0e4f0228ef6",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-24202-yokkaichi-shi-2022",
        "city_name": "三重県四日市市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-24202-yokkaichi-shi-2022",
        "citygml": "f3a2a85c-e1a8-40d8-8c70-c8be6f77ebfa",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-26100-kyoto-shi-2022",
        "city_name": "京都府京都市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-26100-kyoto-shi-2022",
        "citygml": "3da2e055-45a8-4212-bc0e-e769e5f58683",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-26100-kyoto-shi-2023",
        "city_name": "京都府京都市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-26100-kyoto-shi-2023",
        "citygml": "9292dfab-8ee0-49f8-bf6e-81b6ea62a8b3",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-27204-ikeda-shi-2020",
        "city_name": "大阪府池田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27204-ikeda-shi-2020",
        "citygml": "e293ad7f-cff4-48a4-ac0d-8a95ec80a6a5",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-27204-ikeda-shi-2020",
        "city_name": "大阪府池田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27204-ikeda-shi-2020",
        "citygml": "158f4b16-16b8-4daf-8a75-a73f80b7d122",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-27204-ikeda-shi-2020",
        "city_name": "大阪府池田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27204-ikeda-shi-2020",
        "citygml": "8c1b439c-893c-435c-a850-7c91721ede63",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-27219-izumi-shi-2023",
        "city_name": "大阪府和泉市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27219-izumi-shi-2023",
        "citygml": "31abf955-aad8-4c0f-8dff-1129804ceb8c",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-27100-osaka-shi-2020",
        "city_name": "大阪府大阪市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27100-osaka-shi-2020",
        "citygml": "b82f27a0-35c5-4f2b-9963-52b9dbcc042f",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-27100-osaka-shi-2020",
        "city_name": "大阪府大阪市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27100-osaka-shi-2020",
        "citygml": "de8fd635-f08c-4143-b22e-c145e695dc43",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-27100-osaka-shi-2022",
        "city_name": "大阪府大阪市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27100-osaka-shi-2022",
        "citygml": "6ead0f1d-abdb-488a-8fb8-ceff5fb6c46a",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-27100-osaka-shi-2022",
        "city_name": "大阪府大阪市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27100-osaka-shi-2022",
        "citygml": "63ba6765-6d33-4f44-9abb-3fa8000c2b3f",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-27221-kashiwara-shi-2022",
        "city_name": "大阪府柏原市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27221-kashiwara-shi-2022",
        "citygml": "2a76cbb0-b662-4c5a-a7e0-c1e7a5fefdfb",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-27221-kashiwara-shi-2022",
        "city_name": "大阪府柏原市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27221-kashiwara-shi-2022",
        "citygml": "59662350-46eb-4549-a3b8-29227ad56b85",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-27216-kawachinagano-shi-2022",
        "city_name": "大阪府河内長野市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27216-kawachinagano-shi-2022",
        "citygml": "9ae655e2-a0b5-4d8d-8ade-6405abfc2a8e",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-27216-kawachinagano-shi-2023",
        "city_name": "大阪府河内長野市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27216-kawachinagano-shi-2023",
        "citygml": "8635fe28-ebc1-42c6-94c2-0749a2e1a05c",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-27140-sakai-shi-2022",
        "city_name": "大阪府堺市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27140-sakai-shi-2022",
        "citygml": "8f0b76f4-d322-4e2c-b2de-0cb3ec194cb3",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-27140-sakai-shi-2022",
        "city_name": "大阪府堺市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27140-sakai-shi-2022",
        "citygml": "549d1361-0f67-4ec9-86b8-9577d7684f0d",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-27224-settsu-shi-2020",
        "city_name": "大阪府摂津市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27224-settsu-shi-2020",
        "citygml": "86bb5a25-2d07-4b51-a04c-67346c690a63",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-27224-settsu-shi-2020",
        "city_name": "大阪府摂津市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27224-settsu-shi-2020",
        "citygml": "20368530-0580-4fa7-8c77-fb3e94b40893",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-27224-settsu-shi-2020",
        "city_name": "大阪府摂津市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27224-settsu-shi-2020",
        "citygml": "a4eaa3a3-8edc-49db-99f9-9815490cc5fe",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-27207-takatsuki-shi-2020",
        "city_name": "大阪府高槻市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27207-takatsuki-shi-2020",
        "citygml": "49f0ec96-f0aa-4d2f-900c-adca9b319e4c",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-27207-takatsuki-shi-2020",
        "city_name": "大阪府高槻市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27207-takatsuki-shi-2020",
        "citygml": "38c43bb9-ddc8-4a89-aa50-c93d2f3bd8d2",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-27207-takatsuki-shi-2020",
        "city_name": "大阪府高槻市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27207-takatsuki-shi-2020",
        "citygml": "d58a6a37-14dd-4584-a0eb-43c026e705e1",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-27341-tadaoka-cho-2020",
        "city_name": "大阪府忠岡町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27341-tadaoka-cho-2020",
        "citygml": "1e1d303a-9325-462a-8b5f-39f04b200bc7",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-27341-tadaoka-cho-2020",
        "city_name": "大阪府忠岡町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27341-tadaoka-cho-2020",
        "citygml": "54316676-c642-4a77-8dd6-ffe1d11b2950",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-27341-tadaoka-cho-2020",
        "city_name": "大阪府忠岡町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27341-tadaoka-cho-2020",
        "citygml": "f425d011-2d9c-41e6-bb84-d02e5e4a4b04",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-27203-toyonaka-shi-2020",
        "city_name": "大阪府豊中市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27203-toyonaka-shi-2020",
        "citygml": "8d4956af-7ce4-42fc-a166-0123c7a16a08",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-27203-toyonaka-shi-2020",
        "city_name": "大阪府豊中市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27203-toyonaka-shi-2020",
        "citygml": "2b40d5cf-27b4-4765-95a5-4a479d265ddd",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-27203-toyonaka-shi-2020",
        "city_name": "大阪府豊中市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-27203-toyonaka-shi-2020",
        "citygml": "25973afa-4fc8-4d4c-a3a6-f8b2b8efebec",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-28225-asago-shi-2022",
        "city_name": "兵庫県朝来市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-28225-asago-shi-2022",
        "citygml": "7f7e3526-d940-41b2-b876-19aa27a27324",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-28225-asago-shi-2022",
        "city_name": "兵庫県朝来市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-28225-asago-shi-2022",
        "citygml": "c0160066-1c17-4920-a88d-b7bca4443951",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-28210-kakogawa-shi-2020",
        "city_name": "兵庫県加古川市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-28210-kakogawa-shi-2020",
        "citygml": "2213b85d-e0a6-4b0a-a74d-c87d5c20e3a3",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-28210-kakogawa-shi-2020",
        "city_name": "兵庫県加古川市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-28210-kakogawa-shi-2020",
        "citygml": "2de2a25b-b3d1-48db-a365-067e88272e66",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-28210-kakogawa-shi-2020",
        "city_name": "兵庫県加古川市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-28210-kakogawa-shi-2020",
        "citygml": "8ec3a81f-5968-449d-8a65-08a1271bc3f2",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-28201-himeji-shi-2023",
        "city_name": "兵庫県姫路市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-28201-himeji-shi-2023",
        "citygml": "4cc12e1a-0d35-46e5-bf04-72319db379b7",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-28215-miki-shi-2023",
        "city_name": "兵庫県三木市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-28215-miki-shi-2023",
        "citygml": "a2ce6000-3da2-4b3b-93e6-395fe069233f",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-30422-taiji-cho-2021",
        "city_name": "和歌山県太地町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-30422-taiji-cho-2021",
        "citygml": "30e69dff-a10e-4391-ae5d-eed37edaca80",
        "spec": "3",
        "version": "2021",
        "latest": True,
    },
    {
        "dataset_id": "plateau-30422-taiji-cho-2021",
        "city_name": "和歌山県太地町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-30422-taiji-cho-2021",
        "citygml": "021bba37-7720-4eb4-9445-0626ffdbf23b",
        "spec": "2",
        "version": "2021",
    },
    {
        "dataset_id": "plateau-30201-wakayama-shi-2022",
        "city_name": "和歌山県和歌山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-30201-wakayama-shi-2022",
        "citygml": "33c59d3e-0840-4c24-9246-9b11abaedcb0",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-30201-wakayama-shi-2023",
        "city_name": "和歌山県和歌山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-30201-wakayama-shi-2023",
        "citygml": "2617dc11-b7d1-42ea-9cc5-139dddafb392",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-33211-bizen-shi-2023",
        "city_name": "岡山県備前市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-33211-bizen-shi-2023",
        "citygml": "edc9cd24-e88b-43c2-aa87-87bdc6df2550",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-31204-sakaiminato-shi-2022",
        "city_name": "鳥取県境港市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-31204-sakaiminato-shi-2022",
        "citygml": "22a131fc-f836-483d-b3db-3cbf55ad55f8",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-31204-sakaiminato-shi-2022",
        "city_name": "鳥取県境港市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-31204-sakaiminato-shi-2022",
        "citygml": "357d6ecc-9ffb-48f1-9092-1535e2675026",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-31201-tottori-shi-2020",
        "city_name": "鳥取県鳥取市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-31201-tottori-shi-2020",
        "citygml": "6d6fcae3-cb37-4bff-b416-3ad33478cae2",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-31201-tottori-shi-2020",
        "city_name": "鳥取県鳥取市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-31201-tottori-shi-2020",
        "citygml": "6741eb3c-84f4-4439-8dbb-654de69f6635",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-31201-tottori-shi-2020",
        "city_name": "鳥取県鳥取市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-31201-tottori-shi-2020",
        "citygml": "6f8355f0-0d2d-485c-b1c0-85ac9929dd8d",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-31384-hiezu-son-2023",
        "city_name": "鳥取県日吉津村",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-31384-hiezu-son-2023",
        "citygml": "d0e0ca5c-982a-4487-ad48-a407fa788f0f",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-31202-yonago-shi-2023",
        "city_name": "鳥取県米子市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-31202-yonago-shi-2023",
        "citygml": "4201f973-923f-48fa-9c89-603def2b423c",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-34304-kaita-cho-2021",
        "city_name": "広島県海田町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34304-kaita-cho-2021",
        "citygml": "132fbd10-7d3a-4ca9-b974-72db9f69fe1a",
        "spec": "3",
        "version": "2021",
        "latest": True,
    },
    {
        "dataset_id": "plateau-34304-kaita-cho-2021",
        "city_name": "広島県海田町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34304-kaita-cho-2021",
        "citygml": "b7f7ccc1-2008-4cde-8b71-cb673d2a073b",
        "spec": "2",
        "version": "2021",
    },
    {
        "dataset_id": "plateau-34202-kure-shi-2020",
        "city_name": "広島県呉市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34202-kure-shi-2020",
        "citygml": "0e3dab08-1ade-4115-a7da-1b496dcd164b",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-34202-kure-shi-2020",
        "city_name": "広島県呉市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34202-kure-shi-2020",
        "citygml": "f211a619-4832-445c-b683-31447d6d082a",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-34202-kure-shi-2020",
        "city_name": "広島県呉市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34202-kure-shi-2020",
        "citygml": "9f10c73f-c073-40e5-ac14-e429c32c3b15",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-34203-takehara-shi-2023",
        "city_name": "広島県竹原市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34203-takehara-shi-2023",
        "citygml": "b7638248-0986-476c-8ab4-580c9fcb0012",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-34100-hirosima-shi-2022",
        "city_name": "広島県広島市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34100-hirosima-shi-2022",
        "citygml": "cd9cf494-84f7-4c59-af3d-ed47d9663dcf",
        "spec": "2",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-34207-fukuyama-shi-2020",
        "city_name": "広島県福山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34207-fukuyama-shi-2020",
        "citygml": "7248f5c4-9224-4c4a-8ea9-b040eb2c618a",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-34207-fukuyama-shi-2020",
        "city_name": "広島県福山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34207-fukuyama-shi-2020",
        "citygml": "8e32d265-53d4-41d6-b54c-30b628fc3263",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-34207-fukuyama-shi-2020",
        "city_name": "広島県福山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34207-fukuyama-shi-2020",
        "citygml": "b7076aa0-40de-4eab-a863-064ae600ff1d",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-34208-fuchu-shi-2022",
        "city_name": "広島県府中市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34208-fuchu-shi-2022",
        "citygml": "dfd816e3-034e-458d-a70a-950db194737d",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-34208-fuchu-shi-2022",
        "city_name": "広島県府中市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34208-fuchu-shi-2022",
        "citygml": "733b4687-1a4e-415a-84a0-c98f44513814",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-34209-miyoshi-shi-2022",
        "city_name": "広島県三次市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34209-miyoshi-shi-2022",
        "citygml": "81930891-7e61-49dc-85db-53cf7ba90e97",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-34209-miyoshi-shi-2022",
        "city_name": "広島県三次市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-34209-miyoshi-shi-2022",
        "citygml": "8ced6d1c-38ce-4345-88b5-b71cfd020c45",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-36201-tokushima-shi-2023",
        "city_name": "徳島県徳島市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-36201-tokushima-shi-2023",
        "citygml": "2297a05a-99d8-4969-a550-b460107c3a66",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-37206-sanuki-shi-2023",
        "city_name": "香川県さぬき市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-37206-sanuki-shi-2023",
        "citygml": "7fb6ec79-0edb-4410-922b-89f6d1e5ab30",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-37201-takamatsu-shi-2022",
        "city_name": "香川県高松市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-37201-takamatsu-shi-2022",
        "citygml": "6130e7f0-dc62-45a5-a1fa-2e76b1e44fba",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-37201-takamatsu-shi-2022",
        "city_name": "香川県高松市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-37201-takamatsu-shi-2022",
        "citygml": "48ac360d-6c98-43d6-aeec-9a7510ca53bb",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-38215-toon-shi-2023",
        "city_name": "愛媛県東温市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-38215-toon-shi-2023",
        "citygml": "8bc07200-3f2d-4ce6-a19a-0f904e31ac01",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-38201-matsuyama-shi-2020",
        "city_name": "愛媛県松山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-38201-matsuyama-shi-2020",
        "citygml": "bf92bc6d-f65e-4014-8d07-0773984476bd",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-38201-matsuyama-shi-2020",
        "city_name": "愛媛県松山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-38201-matsuyama-shi-2020",
        "citygml": "84dbfd5f-87de-4d3b-81e8-9eb1b9c3d132",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-38201-matsuyama-shi-2020",
        "city_name": "愛媛県松山市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-38201-matsuyama-shi-2020",
        "citygml": "6cfb40c0-875a-45ec-a0da-32157af8b15b",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-40205-iizuka-shi-2020",
        "city_name": "福岡県飯塚市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40205-iizuka-shi-2020",
        "citygml": "713727f1-3aad-46fa-93fb-bf73891bdd9b",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-40205-iizuka-shi-2020",
        "city_name": "福岡県飯塚市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40205-iizuka-shi-2020",
        "citygml": "194aaa4f-cdcc-453c-9dfd-6703623abc54",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-40205-iizuka-shi-2020",
        "city_name": "福岡県飯塚市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40205-iizuka-shi-2020",
        "citygml": "34da8e32-7f3b-4a61-87da-2f55d6b563b2",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-40225-ukiha-shi-2022",
        "city_name": "福岡県うきは市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40225-ukiha-shi-2022",
        "citygml": "ff501855-b467-4d90-9217-48173a469cc4",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-40225-ukiha-shi-2023",
        "city_name": "福岡県うきは市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40225-ukiha-shi-2023",
        "citygml": "3c4c8363-799b-415f-93cc-32ad5638c7a4",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-40202-omuta-shi-2023",
        "city_name": "福岡県大牟田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40202-omuta-shi-2023",
        "citygml": "df263086-ae87-44b8-826e-02e70c24b7cc",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-40100-kitakyushu-shi-2020",
        "city_name": "福岡県北九州市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40100-kitakyushu-shi-2020",
        "citygml": "198351d3-3dc6-474a-abd9-0ba14b4f0aa0",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-40100-kitakyushu-shi-2020",
        "city_name": "福岡県北九州市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40100-kitakyushu-shi-2020",
        "citygml": "db4a6dd3-22a5-47a6-a0c5-c2d03102d512",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-40100-kitakyushu-shi-2020",
        "city_name": "福岡県北九州市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40100-kitakyushu-shi-2020",
        "citygml": "a393587f-b4bf-4cc9-b5c3-23bbe20572c9",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-40203-kurume-shi-2020",
        "city_name": "福岡県久留米市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40203-kurume-shi-2020",
        "citygml": "51fe97b0-7111-421f-babd-8295a5657050",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-40203-kurume-shi-2020",
        "city_name": "福岡県久留米市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40203-kurume-shi-2020",
        "citygml": "dfa7da82-94e0-4420-8190-808d03c318e3",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-40203-kurume-shi-2020",
        "city_name": "福岡県久留米市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40203-kurume-shi-2020",
        "citygml": "66e8e343-05e8-4850-8cd6-c7c97c432f2e",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-40130-fukuoka-shi-2022",
        "city_name": "福岡県福岡市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40130-fukuoka-shi-2022",
        "citygml": "3d13dea9-f74e-4d2f-a91f-fa4718841190",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-40130-fukuoka-shi-2022",
        "city_name": "福岡県福岡市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40130-fukuoka-shi-2022",
        "citygml": "f1fa5f41-b876-47bb-b54c-766f0657d1c0",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-40220-munakata-shi-2020",
        "city_name": "福岡県宗像市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40220-munakata-shi-2020",
        "citygml": "62f60413-4909-4a66-a947-b7369a5dd1ed",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-40220-munakata-shi-2020",
        "city_name": "福岡県宗像市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40220-munakata-shi-2020",
        "citygml": "65b0ed4b-1a74-4624-b09c-00d8f1adacff",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-40220-munakata-shi-2020",
        "city_name": "福岡県宗像市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40220-munakata-shi-2020",
        "citygml": "345e8989-2cab-4e26-8174-a344d8ee1b5d",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-41423-omachi-cho-2022",
        "city_name": "佐賀県大町町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-41423-omachi-cho-2022",
        "citygml": "6c040e82-c884-4dd6-aa17-1c6aa6caa716",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-41423-omachi-cho-2022",
        "city_name": "佐賀県大町町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-41423-omachi-cho-2022",
        "citygml": "2924c864-e79d-407d-9b38-845559733606",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-41208-ogi-shi-2022",
        "city_name": "佐賀県小城市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-41208-ogi-shi-2022",
        "citygml": "40003088-3d37-4ce5-8e60-c0483c8ecf55",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-41208-ogi-shi-2022",
        "city_name": "佐賀県小城市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-41208-ogi-shi-2022",
        "citygml": "18a50707-b4e4-49ce-b1c3-388bbf569fa3",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-41424-kouhoku-machi-2022",
        "city_name": "佐賀県江北町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-41424-kouhoku-machi-2022",
        "citygml": "4d3839d2-3df9-4ab1-86e7-2d4d3d15d4b4",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-41424-kouhoku-machi-2022",
        "city_name": "佐賀県江北町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-41424-kouhoku-machi-2022",
        "citygml": "1d3b5000-305c-4dc4-aebc-277cf225ff30",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-41425-shiroisi-chou-2022",
        "city_name": "佐賀県白石町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-41425-shiroisi-chou-2022",
        "citygml": "6f859562-86d8-4729-a8aa-4315200aece7",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-41425-shiroisi-chou-2022",
        "city_name": "佐賀県白石町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-41425-shiroisi-chou-2022",
        "citygml": "f10717be-cd02-4f98-bb72-2c60cb43935c",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-41206-takeo-shi-2022",
        "city_name": "佐賀県武雄市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-41206-takeo-shi-2022",
        "citygml": "002bc90f-b8e2-4ee1-ae00-962ded54d28d",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-41206-takeo-shi-2022",
        "city_name": "佐賀県武雄市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-41206-takeo-shi-2022",
        "citygml": "71f8ff13-95b7-4dd9-87ee-ffcfcbc32209",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-40447-chikuzen-machi-2023",
        "city_name": "佐賀県筑前町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-40447-chikuzen-machi-2023",
        "citygml": "42fc062e-14fb-46d8-bb14-7d3ebecc9840",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-42202-sasebo-shi-2022",
        "city_name": "長崎県佐世保市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-42202-sasebo-shi-2022",
        "citygml": "1367a801-63c9-406c-8b2b-fcebfbdea49a",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-42202-sasebo-shi-2022",
        "city_name": "長崎県佐世保市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-42202-sasebo-shi-2022",
        "citygml": "d1ed3fc0-eb00-419b-bfe0-c4ed965663d5",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-43204-arao-shi-2020",
        "city_name": "熊本県荒尾市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-43204-arao-shi-2020",
        "citygml": "61499601-e63b-4164-804b-695b54e687c4",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-43204-arao-shi-2020",
        "city_name": "熊本県荒尾市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-43204-arao-shi-2020",
        "citygml": "df61d813-8cf9-4293-a6ef-1e63185d773d",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-43204-arao-shi-2020",
        "city_name": "熊本県荒尾市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-43204-arao-shi-2020",
        "citygml": "f0345e11-2ef0-4600-9b23-402949e43c0f",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-43100-kumamoto-shi-2020",
        "city_name": "熊本県熊本市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-43100-kumamoto-shi-2020",
        "citygml": "1ff69d19-e3d1-4ce2-a51a-74d49bdc91cd",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-43100-kumamoto-shi-2020",
        "city_name": "熊本県熊本市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-43100-kumamoto-shi-2020",
        "citygml": "211ac99a-b176-4f6a-ad7f-4d7d1d0dcf77",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-43100-kumamoto-shi-2022",
        "city_name": "熊本県熊本市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-43100-kumamoto-shi-2022",
        "citygml": "ad7316f0-e299-42e3-9475-2929a150a363",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-43100-kumamoto-shi-2022",
        "city_name": "熊本県熊本市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-43100-kumamoto-shi-2022",
        "citygml": "05b3ba0d-2402-4ca4-99bb-a441323f3b9f",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-43206-tamana-shi-2020",
        "city_name": "熊本県玉名市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-43206-tamana-shi-2020",
        "citygml": "d00958d8-be61-4c0a-8f03-0f5c82ad8f6d",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-43206-tamana-shi-2020",
        "city_name": "熊本県玉名市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-43206-tamana-shi-2020",
        "citygml": "10b6f58a-dbff-4844-963a-c8780fb8bacd",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-43206-tamana-shi-2023",
        "city_name": "熊本県玉名市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-43206-tamana-shi-2023",
        "citygml": "789c4115-a8cf-406e-9e35-2f89d684388b",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-43443-mashiki-machi-2020",
        "city_name": "熊本県益城町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-43443-mashiki-machi-2020",
        "citygml": "5837dc9c-75ca-4a59-a94d-573af4b564b2",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-43443-mashiki-machi-2020",
        "city_name": "熊本県益城町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-43443-mashiki-machi-2020",
        "citygml": "a9cfbc79-c00f-4698-95fb-2b8f9a538f60",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-43443-mashiki-machi-2023",
        "city_name": "熊本県益城町",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-43443-mashiki-machi-2023",
        "citygml": "9935bb35-8832-4a27-b8ed-c872069bd520",
        "spec": "3",
        "version": "2023",
        "latest": True,
    },
    {
        "dataset_id": "plateau-44204-hita-shi-2020",
        "city_name": "大分県日田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-44204-hita-shi-2020",
        "citygml": "5fb9d857-9318-4244-8e35-b91282f5e076",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-44204-hita-shi-2020",
        "city_name": "大分県日田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-44204-hita-shi-2020",
        "citygml": "42dc572f-28ec-470b-acf2-c007177e6e14",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-44204-hita-shi-2020",
        "city_name": "大分県日田市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-44204-hita-shi-2020",
        "citygml": "72cac244-9c3e-4ab4-afad-74ad0cc3ad80",
        "spec": "1",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-45203-nobeoka-shi-2022",
        "city_name": "宮崎県延岡市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-45203-nobeoka-shi-2022",
        "citygml": "95420f15-6688-4796-9829-bbf39dde01dc",
        "spec": "3",
        "version": "2022",
        "latest": True,
    },
    {
        "dataset_id": "plateau-45203-nobeoka-shi-2022",
        "city_name": "宮崎県延岡市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-45203-nobeoka-shi-2022",
        "citygml": "2aca8a01-32e4-406f-a4c4-92f95b99a9c0",
        "spec": "2",
        "version": "2022",
    },
    {
        "dataset_id": "plateau-47201-naha-shi-2020",
        "city_name": "沖縄県那覇市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-47201-naha-shi-2020",
        "citygml": "6ed292c8-6d45-41b9-b933-b83ab4c1ec0f",
        "spec": "3",
        "version": "2020",
        "latest": True,
    },
    {
        "dataset_id": "plateau-47201-naha-shi-2020",
        "city_name": "沖縄県那覇市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-47201-naha-shi-2020",
        "citygml": "59819ec2-c617-4508-9827-994cf7b4cae6",
        "spec": "2",
        "version": "2020",
    },
    {
        "dataset_id": "plateau-47201-naha-shi-2020",
        "city_name": "沖縄県那覇市",
        "homepage": "https://www.geospatial.jp/ckan/dataset/plateau-47201-naha-shi-2020",
        "citygml": "e651e398-f3b2-4cfa-a437-70ce2ccc2296",
        "spec": "1",
        "version": "2020",
    },
]


def _build_city_list(base_city_list):
    from copy import deepcopy

    result = []
    for city in base_city_list:
        if city.get("latest", False):
            result.append(deepcopy(city))

        city["dataset_id"] = f"{city['dataset_id']}.v{city['spec']}"
        if "latest" in city:
            del city["latest"]
        result.append(city)

    return result


city_list = _build_city_list(base_city_list)

# import json

# print(json.dumps(city_list, ensure_ascii=False, indent=2))

# # %%
# import requests

# resp = requests.get("https://www.geospatial.jp/ckan/dataset/plateau")

# # %%
# import re
# from lxml import html

# # print(resp.text)

# root = html.fromstring(resp.text)
# el = root.find_class("embedded-content")[0]
# content = html.tostring(el, encoding="unicode")
# content = content.replace("\n", "")
# # print(content)

# m_all = re.findall(
#     r"strong>(.*?)</strong>(.*?)<p><", content
# )  # TODO: include last one!
# m_all = m_all[3:]

# # print(len(m), m)

# result = []

# for pref_name, pref_part in m_all:
#     # if pref_name == "茨城県":
#     #     print(pref_name, pref_part)
#     m_cities = re.findall(
#         r'<a href="https://www.geospatial.jp/ckan/dataset/(.*?)" title="(.*?)(\d\d\d\d)">.*?</a>',
#         pref_part,
#     )
#     # print(pref_name)
#     # print(m_cities)

#     for dataset_id, name, year in m_cities:
#         result.append(
#             {
#                 "dataset_id": dataset_id,
#                 "city_name": pref_name + name,
#                 "homepage": f"https://www.geospatial.jp/ckan/dataset/{dataset_id}",
#                 # "citygml": None,
#                 # "3dtiles": None,
#             }
#         )

# import json

# # print(json.dumps(result, ensure_ascii=False, indent=2))

# # %%
# from time import sleep

# invalid = []

# # NOTE: Check url validity
# for city in result:
#     resp = requests.get(city["homepage"])
#     text = resp.text  # .replace("\n", "")
#     ms = re.findall(
#         r'<a class="heading" href=".*?/resource/(.*?)" title="(CityGML.*?)">', text
#     )
#     print(len(ms), city["dataset_id"])
#     if len(ms) == 0:
#         invalid.append(city)
#     sleep(0.5)

# print(invalid)

# # %%
# replacement = {
#     "plateau-22429-kawane-honcho-2023": "plateau-22429-kawanehon-cho-2023",
#     "plateau-22306-nishi-izu-cho-2023": "plateau-22306-nishiizu-cho-2023",
# }

# for i, city in enumerate(result):
#     if city["dataset_id"] in replacement:
#         dataset_id = replacement[city["dataset_id"]]
#         result[i]["dataset_id"] = dataset_id
#         result[i]["homepage"] = f"https://www.geospatial.jp/ckan/dataset/{dataset_id}"


# # %%

# # diff1 = {x["dataset_id"] for x in city_list} - {x["dataset_id"] for x in result}
# diff2 = {x["dataset_id"] for x in result} - {x["dataset_id"] for x in city_list}
# diff2

# # %%
# from time import sleep
# from copy import deepcopy

# final_result = []

# for city in result:
#     # if city["dataset_id"] not in diff2:
#     #     city = next(x for x in city_list if x["dataset_id"] == city["dataset_id"])
#     #     final_result.append(city)
#     #     continue
#     resp = requests.get(city["homepage"])
#     text = resp.text  # .replace("\n", "")

#     ms = re.findall(
#         r'<a class="heading" href=".*?/resource/(.*?)" title="(CityGML.*?)">', text
#     )

#     print(city["dataset_id"])

#     if len(ms) == 0:
#         print("No CityGML found")
#         # plateau-15202-nagaoka-shi-2023

#         input()
#         continue

#     for i, m in enumerate(ms):
#         print(i, m)
#         # spec = input("Enter spec: ")
#         city["citygml"] = m[0]
#         city["spec"] = m[1]
#         _city = deepcopy(city)
#         final_result.append(_city)

#     sleep(0.5)

# print(json.dumps(final_result, ensure_ascii=False, indent=2))
# # for city in city_list:
# #     print({"dataset_id": re.match("https://www.geospatial.jp/ckan/dataset/(.*)", city[1]).group(1), "city_name": city[0], "homepage": city[1]}, ",")

# # for city in city_list:
# #     print(
# #         f'"{city["dataset_id"]}": {{ "city_name": "{city["city_name"]}", "homepage": "{city["homepage"]}"}},'
# #     )

# # %%
# # NOTE: Set version

# import re

# new_city_list = []

# for city in city_list:
#     try:
#         dataset_id = city["dataset_id"]
#         m = re.match(r".*-(\d\d\d\d)", dataset_id)
#         year = m.group(1)
#         city["version"] = year
#     except:
#         print(city)
#         year = input("year:")
#         city["version"] = year

#     new_city_list.append(city)


# new_city_list

# # %%
# # NOTE: Set latest

# new_city_list = []

# for city in city_list:
#     if [x["city_name"] for x in city_list].count(city["city_name"]) == 1:
#         city["latest"] = True
#     else:
#         cities = [x for x in city_list if x["city_name"] == city["city_name"]]
#         latest_year = max([int(x["version"]) for x in cities])
#         latest_spec = max(
#             [int(x["spec"]) for x in cities if x["version"] == str(latest_year)]
#         )
#         if city["version"] == str(latest_year) and city["spec"] == str(latest_spec):
#             city["latest"] = True

#     new_city_list.append(city)

# new_city_list
